# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class RegularLimitParameters(google___protobuf___message___Message):
    time = ... # type: int
    branches = ... # type: int
    failures = ... # type: int
    solutions = ... # type: int
    smart_time_check = ... # type: bool
    cumulative = ... # type: bool

    def __init__(self,
        *,
        time : typing___Optional[int] = None,
        branches : typing___Optional[int] = None,
        failures : typing___Optional[int] = None,
        solutions : typing___Optional[int] = None,
        smart_time_check : typing___Optional[bool] = None,
        cumulative : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RegularLimitParameters: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"branches",u"cumulative",u"failures",u"smart_time_check",u"solutions",u"time"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"branches",b"branches",u"cumulative",b"cumulative",u"failures",b"failures",u"smart_time_check",b"smart_time_check",u"solutions",b"solutions",u"time",b"time"]) -> None: ...
